@@ -10,14 +10,10 @@
 ( cd opt/kde/lib ; ln -sf libcatalogmanager.so.1.0.0 libcatalogmanager.so.1 )
 ( cd opt/kde/lib ; rm -rf libkbabel.so )
 ( cd opt/kde/lib ; ln -sf libkbabel.so.1.0.0 libkbabel.so )
-( cd opt/kde/lib ; rm -rf libktrace.so.1 )
-( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so.1 )
 ( cd opt/kde/lib ; rm -rf libcervisia.so )
 ( cd opt/kde/lib ; ln -sf libcervisia.so.1.0.0 libcervisia.so )
 ( cd opt/kde/lib ; rm -rf libkbabeldict.so.1 )
 ( cd opt/kde/lib ; ln -sf libkbabeldict.so.1.0.0 libkbabeldict.so.1 )
-( cd opt/kde/lib ; rm -rf libktrace.so )
-( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so )
 ( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so )
 ( cd opt/kde/lib ; ln -sf libkbabeldictplugin.so.1.0.0 libkbabeldictplugin.so )
 ( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so.1 )
